
# 更新日志
  * [2.5.x](https://www.layui.com/doc/base/changelog.html#2-5-x) 
  * [2.4.x](https://www.layui.com/doc/base/changelog.html#2-4-x)     
  * [2.3.0](https://www.layui.com/doc/base/changelog.html#2-3-0)
  * [2.2.6](https://www.layui.com/doc/base/changelog.html#2-2-6)
  * [2.2.5](https://www.layui.com/doc/base/changelog.html#2-2-5)
  * [2.2.4](https://www.layui.com/doc/base/changelog.html#2-2-45)
  * [2.2.3](https://www.layui.com/doc/base/changelog.html#2-2-3)
  * [2.2.2](https://www.layui.com/doc/base/changelog.html#2-2-2)
  * [2.2.1](https://www.layui.com/doc/base/changelog.html#2-2-1)
  * [2.2.0](https://www.layui.com/doc/base/changelog.html#2-2-0)
  * [2.1.7](https://www.layui.com/doc/base/changelog.html#2-1-7)
  * [2.1.6](https://www.layui.com/doc/base/changelog.html#2-1-6)
  * [2.1.5](https://www.layui.com/doc/base/changelog.html#2-1-5)
  * [2.1.4](https://www.layui.com/doc/base/changelog.html#2-1-4)
  * [2.1.3](https://www.layui.com/doc/base/changelog.html#2-1-3)
  * [2.1.2](https://www.layui.com/doc/base/changelog.html#2-1-2)
  * [2.1.1](https://www.layui.com/doc/base/changelog.html#2-1-1)
  * [2.1.0](https://www.layui.com/doc/base/changelog.html#2-1-0)
  * [2.0.2](https://www.layui.com/doc/base/changelog.html#2-0-2)
  * [2.0.1](https://www.layui.com/doc/base/changelog.html#2-0-1)
  * [2.0.0](https://www.layui.com/doc/base/changelog.html#2-0-0)
